#
# spec file
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-hatch-fancy-pypi-readme%{psuffix}
Version:        24.1.0
Release:        1.5
Summary:        Fancy PyPI READMEs with Hatch
License:        MIT
URL:            https://github.com/hynek/hatch-fancy-pypi-readme
Source:         https://files.pythonhosted.org/packages/source/h/hatch-fancy-pypi-readme/hatch_fancy_pypi_readme-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-generators
BuildRequires:  python-rpm-macros
%if %{with test}
# SECTION test
BuildRequires:  %{python_module hatch-fancy-pypi-readme >= %version}
BuildRequires:  %{python_module pytest}
# /SECTION
%endif
Requires(post): update-alternatives
Requires(postun):update-alternatives
Provides:       python-hatch_fancy_pypi_readme = %{version}-%{release}
BuildArch:      noarch
%{?python_enable_dependency_generator}
%python_subpackages

%description
hatch_fancy_pypi_readme is a Hatch metadata plugin for everyone who cares about
the first impression of their project's PyPI landing page. It allows you to
define your PyPI project description in terms of concatenated fragments that
are based on static strings, files, and most importantly: parts of files
defined using cut-off points or regular expressions.

Once you've assembled your readme, you can additionally run regular
expression-based substitutions over it. For instance to make relative links
absolute or to linkify users and issue numbers in your changelog.

Do you want your PyPI readme to be the project readme, but without badges,
followed by the license file, and the changelog section for only the last
release? You've come to the right place!

%prep
%setup -q -n hatch_fancy_pypi_readme-%{version}

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/hatch-fancy-pypi-readme
%endif

%check
%if %{with test}
#test_end_to_end want's to have a hatchling wheel
%pytest --ignore tests/test_end_to_end.py
%endif

%post
%python_install_alternative hatch-fancy-pypi-readme

%postun
%python_uninstall_alternative hatch-fancy-pypi-readme

%if !%{with test}
%files %{python_files}
%license LICENSE.txt
%doc README.md
%python_alternative %{_bindir}/hatch-fancy-pypi-readme
%{python_sitelib}/hatch_fancy_pypi_readme
%{python_sitelib}/hatch_fancy_pypi_readme-%{version}*-info
%endif

%changelog
* Sun Jan  7 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 24.1.0:
  The last release [broke
  _scikit-build-core_](https://github.com/scikit-build/scikit-build-core/issues/592)
  so this one adds a default argument value. No user-visible
  changes.
  * Added a default to an internal API that is used by
  * scikit-build-core*.
* Sun Jan  7 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 23.2.0:
  There's only one change but I think it's really cool: you can now
  add the package version into your PyPI readme by adding the
  string `$HFPR_VERSION` to it!
  * `$HFPR_VERSION` is now replaced by the package version in the
    PyPI readme. The version is not available in CLI mode, therefore
    it's replaced by the dummy value of `42.0`.
* Mon May 22 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 23.1.0 (there is no 23.0.0):
  The only change is that our CLI now also takes the presence of an
  hatch.toml file into account.
  The packaging side always supported it.
* Tue May 16 2023 Dirk Müller <dmueller@suse.com>
- break dependency cycle between attrs (pulled by pytest) and pytest-hatch-fancy-pypi-readme
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Tue Oct 11 2022 Ben Greiner <code@bnavigator.de>
- Clean up specfile: remove hatch from BuildRequires footprint
- Enable testsuite except for end-to-end which would need extra
  wheelfiles
* Tue Oct  4 2022 Johannes Kastl <kastl@b1-systems.de>
- update to 22.8.0:
  * The only change is a new feature for file fragments:
    start-at which behaves like start-after, but preserves the string that
    is searched for.
    Here's a real-world example of how it can simplify your configuration.
* Mon Sep 26 2022 Johannes Kastl <kastl@b1-systems.de>
- new package python-hatch-fancy-pypi-readme
